/**
 *
 * Copyright (C) 2011 Cloud Conscious, LLC. <info@cloudconscious.com>
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */
package org.jclouds.vcloud.predicates;

import static com.google.common.base.Preconditions.checkNotNull;

import org.jclouds.vcloud.domain.ovf.ResourceAllocation;
import org.jclouds.vcloud.domain.ovf.ResourceType;

import com.google.common.base.Predicate;

/**
 * 
 * @author Adrian Cole
 */
public class VCloudPredicates {

   /**
    * Return resource allocations of the specific type.
    * 
    * @param type
    *           type to match the items
    * @return predicate
    */
   public static Predicate<ResourceAllocation> resourceType(final ResourceType type) {
      checkNotNull(type, "type");
      return new Predicate<ResourceAllocation>() {
         @Override
         public boolean apply(ResourceAllocation in) {
            return type.equals(in.getType());
         }

         @Override
         public String toString() {
            return "resourceAllocationType(" + type + ")";
         }
      };
   }
}
